@@ -48,4 +48,14 @@ convertplot <- function(exp){
     return(p)
 }
 
+##' blank theme
+##' @importFrom ggplot2 theme
+##' @importFrom ggplot2 element_blank
+##'
+.theme_blank<-function(){
+    theme(panel.border=element_blank(),panel.grid=element_blank(),
+        panel.background=element_blank(),axis.ticks=element_blank(),
+        axis.text=element_blank(),
+        axis.title=element_blank(),legend.position="none")
+}
 
